@@ -3,7 +3,7 @@ use 5.008;
 use warnings;
 use strict;
 
-our $VERSION = '1.59';
+our $VERSION = '1.60';
 
 use Carp;
 use Data::Compare;
@@ -1218,6 +1218,10 @@ __END__
 Devel::Examine::Subs - Get info about, search/replace and inject code into
 Perl files and subs.
 
+=for html
+<a href="http://travis-ci.org/stevieb9/devel-examine-subs"><img src="https://secure.travis-ci.org/stevieb9/devel-examine-subs.png"/>
+<a href='https://coveralls.io/github/stevieb9/devel-examine-subs?branch=master'><img src='https://coveralls.io/repos/stevieb9/devel-examine-subs/badge.svg?branch=master&service=github' alt='Coverage Status' /></a>
+
 =head1 SYNOPSIS
 
     use Devel::Examine::Subs;
@@ -1883,22 +1887,14 @@ will be executed based on their order in the array reference.
 
 =head1 REPOSITORY
 
-=begin html
- 
-<a href="http://travis-ci.org/stevieb9/devel-examine-subs"><img src="https://secure.travis-ci.org/stevieb9/devel-examine-subs.png"/></a> <a href="https://coveralls.io/r/stevieb9/devel-examine-subs"><img src="https://coveralls.io/repos/stevieb9/devel-examine-subs.png?branch=master"/></a>
- 
-=end html
+
 
 L<https://github.com/stevieb9/devel-examine-subs>
 
 =head1 BUILD REPORTS
 
-Travis-CI: L<https://travis-ci.org/stevieb9/devel-examine-subs>
-
 CPAN Testers: L<http://matrix.cpantesters.org/?dist=Devel-Examine-Subs>
 
-Coverage: L<https://coveralls.io/github/stevieb9/devel-examine-subs>
-
 =head1 DEBUGGING
 
 If C<Devel::Trace::Subs> is installed, you can configure stack tracing.
